#!/usr/bin/tclsh
########################################################################
# Copyright (c) 2004 by Hartmut Schwarz, matut@matut-spielwerk.de
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2 
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with this program; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
# MA 02111-1307, USA.
########################################################################

# makes the cdrdao audio table of contents (TOC) file 

########################################################################
# configuration section                                                #
########################################################################
fconfigure stdout -encoding iso8859-1
set country "DE";
set owner   "XX1";
set year    "04";
if { "[info hostname]" != "" } { 
 set artist "Csound on [info hostname]"
} else {
 set artist "Csound on unknown computer";
}
set trackinfo "[file dirname $argv0]/trackinfoascii.tcl" ;

########################################################################
# function definition section                                          #
########################################################################

# load common functions
source various.tcl

# print a minimum of help information
proc printhelp { name } {
 puts "$name : create cdrdao audio TOC file for Clockwork-Music CD";
 puts "usage : $argv0 \[-ST|-MA|-IR\] score1 score2 score3 ...";
 puts "        -IR = left/right (stereo) + main signal room response";
 puts "        -MA = main signal (mono) without room response";
 puts "        -ST = left/right (stereo) without room response";
}

########################################################################
# program execution section                                            #
########################################################################

# evaluate mixer mode
set mixmode [eval_mix_mode];
if { $mixmode != "-MA" && $mixmode != "-ST" && $mixmode != "-IR" } {
 printhelp $argv0;
 exit 1;
}
set argc [llength $argv];

# select WAV directory according to mixer mode
if { $mixmode == "-IR" } {
 set dirwav  "[file dirname $argv0]/../../music3";
} elseif { $mixmode == "-MA" } {
 set dirwav  "[file dirname $argv0]/../../music1";
} else {
 set dirwav  "[file dirname $argv0]/../../music2";
}

# turn WAV directory name into a full pathname without ..
set dirwav [file normalize $dirwav];

# Eingabe pruefen
if { $argc < 1 } {
 printhelp $argv0;
 exit 1;
}

# check for sufficient available track info
foreach track $argv {
 if { [catch { exec $trackinfo $track TITLE } result] } {
  puts stderr "*** no TITLE for track \"$track\" ***";
  exit 2;
 }
 if { [catch { exec $trackinfo $track MESSAGE } result] } {
  puts stderr "*** no MESSAGE for track \"$track\" ***";
  exit 3;
 }
 if { [catch { exec $trackinfo $track ID } result] } {
  puts stderr "*** no ID for track \"$track\" ***";
  exit 4;
 } elseif { ![regexp {^[0-9]{5}$} $result] } {
  puts stderr "*** invalid ID \"$result\" for track \"$track\" ***";
  exit 5;
 }
};

puts "CD_ROM_XA";
puts "";
puts "CD_TEXT {";
puts " LANGUAGE_MAP {";
puts "  0 : EN";
puts " }";
puts " LANGUAGE 0 {";
puts "  TITLE \"Clockwork-Music\"";
puts "  PERFORMER \"$artist\"";
puts "  DISC_ID \"MT00001\"";
puts "  UPC_EAN \"\"";
puts "  MESSAGE \"This CD wants to be copied and passed on to your friends.\" }";
puts "}";
foreach track $argv {
 puts "";
 puts "TRACK AUDIO";
 puts "COPY";
 puts "ISRC \"$country$owner$year[exec $trackinfo $track ID]\"";
 puts "CD_TEXT {"
 puts " LANGUAGE 0 {"
 puts "  TITLE \"[exec $trackinfo $track TITLE]\"";
 puts "  PERFORMER \"$artist\"";
 puts "  ISRC \"$country-$owner-$year-[exec $trackinfo $track ID]\""
 puts "  MESSAGE \"[exec $trackinfo $track MESSAGE]\" }";
 puts "}"
 puts "AUDIOFILE \"$dirwav/$track.wav\" 0";
};
